@@ -27,10 +27,6 @@
 (require 'oc-basic)
 (require 'oc-csl)
 
-;; Pre-1.0 API cleanup
-
-(make-obsolete 'citar-org-id-get-create 'citar-org--id-get-create "1.0")
-
 (declare-function org-open-at-point "org")
 (declare-function org-element-property "org-element")
 (declare-function org-element-type "org-element")
@@ -302,12 +298,27 @@ With optional argument FORCE, force the creation of a new ID."
 
 ;;;###autoload
 (defun citar-org-key-at-point ()
+  "Return key at point for org-cite citation-reference or property."
+  (or (citar-org--key-at-point)
+      (citar-org--prop-key-at-point)))
+
+(defun citar-org--key-at-point ()
   "Return key at point for org-cite citation-reference."
   (when-let ((reference (citar-org--reference-at-point)))
     (cons (org-element-property :key reference)
           (cons (org-element-property :begin reference)
                 (org-element-property :end reference)))))
 
+(defun citar-org--prop-key-at-point ()
+  "Return citekey at point, when in org property drawer.
+
+Citkey must be formatted as `@key'."
+  (when (and (equal (org-element-type (org-element-at-point)) 'node-property)
+             (org-in-regexp (concat "[[:space:]]" org-element-citation-key-re)))
+    (cons (substring (match-string 0) 2)
+          (cons (match-beginning 0)
+                (match-end 0)))))
+
 ;;;###autoload
 (defun citar-org-citation-at-point ()
   "Return org-cite citation keys at point as a list for `embark'."
